@@ -7,14 +7,12 @@ Usage::
     import aiotaskq
 
 
-    @aiotaskq.register_task
+    @aiotaskq.task
     def some_task(b: int) -> int:
         # Some task with high cpu usage
         def _naive_fib(n: int) -> int:
-            if n <= 1:
+            if n <= 2:
                 return 1
-            elif n <= 2:
-                return 2
             return _naive_fib(n - 1) + _naive_fib(n - 2)
         return _naive_fib(b)
 
@@ -29,9 +27,14 @@ Usage::
 
 """
 
-from .main import register_task
+from pathlib import Path
 
+import tomlkit
 
-__all__ = [
-    "register_task"
-]
+from .task import task
+
+with Path("pyproject.toml").open("r", encoding="utf-8") as f:
+    toml_dict = tomlkit.loads(f.read())
+    __version__ = toml_dict["project"]["version"]
+
+__all__ = ["__version__", "task"]
